==> owncloud-5.0.17.tar.bz2: owncloud/apps/calendar/l10n/eo.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Ne ĉiuj kalendaroj estas tute kaŝmemorigitaj",
"Everything seems to be completely cached" => "Ĉio ŝajnas tute kaŝmemorigita",
"No calendars found." => "Neniu kalendaro troviĝis.",
"No events found." => "Neniu okazaĵo troviĝis.",
"Wrong calendar" => "Malĝusta kalendaro",
"You do not have the permissions to edit this event." => "Vi ne havas la permeson redakti ĉi tiun okazaĵon.",
"The file contained either no events or all events are already saved in your calendar." => "Aŭ la dosiero enhavas neniun okazaĵon aŭ ĉiuj okazaĵoj jam estas konservitaj en via kalendaro.",
"events has been saved in the new calendar" => "okazaĵoj estas konservitaj en la nova kalendaro",
"Import failed" => "Enporto malsukcesis",
"events has been saved in your calendar" => "okazaĵoj estas konservitaj en via kalendaro",
"New Timezone:" => "Nova horozono:",
"Timezone changed" => "La horozono estas ŝanĝita",
"Invalid request" => "Nevalida peto",
"Calendar" => "Kalendaro",
"Deletion failed" => "Forigo malsukcesis",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd, la d-a de MMMM[ yyyy]{ – [ddd, la d-a de] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd, la d-a de MMMM[ yyyy] HH:mm{ – [ddd, la d-a de MMMM yyyy] HH:mm}",
"user" => "uzanto",
"group" => "grupo",
"Editable" => "Redaktebla",
"Shareable" => "Kunhavigebla",
"Deletable" => "Forigebla",
"ddd" => "ddd",
"ddd M/d" => "ddd d/M",
"dddd M/d" => "dddd d/M",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "d MMM[ yyyy]{ '&#8212;'d[ MMM] yyyy}",
"dddd, MMM d, yyyy" => "dddd, la d-a de MMM yyyy",
"Sunday" => "dimanĉo",
"Monday" => "lundo",
"Tuesday" => "mardo",
"Wednesday" => "merkredo",
"Thursday" => "ĵaŭdo",
"Friday" => "vendredo",
"Saturday" => "sabato",
"Sun." => "dim.",
"Mon." => "lun.",
"Tue." => "mar.",
"Wed." => "mer.",
"Thu." => "ĵaŭ.",
"Fri." => "ven.",
"Sat." => "sab.",
"January" => "Januaro",
"February" => "Februaro",
"March" => "Marto",
"April" => "Aprilo",
"May" => "Majo",
"June" => "Junio",
"July" => "Julio",
"August" => "Aŭgusto",
"September" => "Septembro",
"October" => "Oktobro",
"November" => "Novembro",
"December" => "Decembro",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Maj.",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Aŭg.",
"Sep." => "Sep.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dec.",
"All day" => "La tuta tago",
"New Calendar" => "Nova kalendaro",
"Missing or invalid fields" => "Estas mankantaj aŭ nevalidaj kampoj",
"Title" => "Titolo",
"From Date" => "ekde la dato",
"From Time" => "ekde la horo",
"To Date" => "ĝis la dato",
"To Time" => "ĝis la horo",
"The event ends before it starts" => "La okazaĵo finas antaŭ komenci",
"There was a database fail" => "Datumbaza malsukceso okazis",
"Birthday" => "Naskiĝotago",
"Business" => "Negoco",
"Call" => "Voko",
"Clients" => "Klientoj",
"Deliverer" => "Livero",
"Holidays" => "Ferioj",
"Ideas" => "Ideoj",
"Journey" => "Vojaĝo",
"Jubilee" => "Jubileo",
"Meeting" => "Rendevuo",
"Other" => "Alia",
"Personal" => "Persona",
"Projects" => "Projektoj",
"Questions" => "Demandoj",
"Work" => "Laboro",
"by" => "de",
"unnamed" => "nenomita",
"You do not have the permissions to update this calendar." => "Vi ne havas la permeson ĝisdatigi ĉi tiun kalendaron.",
"You do not have the permissions to delete this calendar." => "Vi ne havas la permeson forigi ĉi tiun kalendaron.",
"You do not have the permissions to add to this calendar." => "Vi ne havas la permeson aldoni al ĉi tiu kalendaro.",
"You do not have the permissions to add events to this calendar." => "Vi ne havas la permeson aldoni okazaĵojn al ĉi tiu kalendaro.",
"You do not have the permissions to delete this event." => "Vi ne havas la permeson forigi ĉi tiun okazaĵon.",
"Does not repeat" => "Ĉi tio ne ripetiĝas",
"Daily" => "Tage",
"Weekly" => "Semajne",
"Every Weekday" => "Labortage",
"Bi-Weekly" => "Semajnduope",
"Monthly" => "Monate",
"Yearly" => "Jare",
"never" => "neniam",
"by occurrences" => "laŭ aperoj",
"by date" => "laŭ dato",
"by monthday" => "laŭ monattago",
"by weekday" => "laŭ semajntago",
"events week of month" => "la monatsemajno de la okazaĵo",
"first" => "unua",
"second" => "dua",
"third" => "tria",
"fourth" => "kvara",
"fifth" => "kvina",
"last" => "lasta",
"by events date" => "laŭ okazaĵdato",
"by yearday(s)" => "laŭ jartago(j)",
"by weeknumber(s)" => "laŭ semajnnumero(j)",
"by day and month" => "laŭ tago kaj monato",
"Date" => "Dato",
"Cal." => "Kal.",
"Week" => "Semajno",
"Month" => "Monato",
"List" => "Listo",
"Today" => "Hodiaŭ",
"Settings" => "Agordo",
"Your calendars" => "Viaj kalendaroj",
"CalDav Link" => "CalDav-a ligilo",
"Share Calendar" => "Kunhavigi kalendaron",
"Download" => "Elŝuti",
"Edit" => "Redakti",
"Delete" => "Forigi",
"New calendar" => "Nova kalendaro",
"Edit calendar" => "Redakti la kalendaron",
"Displayname" => "Montrota nomo",
"Active" => "Aktiva",
"Calendar color" => "Kalendarokoloro",
"Save" => "Konservi",
"Submit" => "Sendi",
"Cancel" => "Nuligi",
"Edit an event" => "Redakti okazaĵon",
"Export" => "Elporti",
"Eventinfo" => "Informo de okazaĵo",
"Repeating" => "Ripetata",
"Alarm" => "Alarmo",
"Attendees" => "Ĉeestontoj",
"Share" => "Kunhavigi",
"Title of the Event" => "Okazaĵotitolo",
"Category" => "Kategorio",
"Separate categories with commas" => "Disigi kategoriojn per komoj",
"Edit categories" => "Redakti kategoriojn",
"All Day Event" => "La tuta tago",
"From" => "Ekde",
"To" => "Ĝis",
"Advanced options" => "Altnivela agordo",
"Location" => "Loko",
"Location of the Event" => "Loko de okazaĵo",
"Description" => "Priskribo",
"Description of the Event" => "Okazaĵopriskribo",
"Repeat" => "Ripeti",
"Advanced" => "Altnivelo",
"Select weekdays" => "Elekti semajntagojn",
"Select days" => "Elekti tagojn",
"and the events day of year." => "kaj la jartago de la okazaĵo.",
"and the events day of month." => "kaj la monattago de la okazaĵo.",
"Select months" => "Elekti monatojn",
"Select weeks" => "Elekti semajnojn",
"and the events week of year." => "kaj la jarsemajno de la okazaĵo.",
"Interval" => "Intervalo",
"End" => "Fino",
"occurrences" => "aperoj",
"create a new calendar" => "Krei novan kalendaron",
"Import a calendar file" => "Enporti kalendarodosieron",
"Please choose a calendar" => "Bonvolu elekti kalendaron",
"Name of new calendar" => "Nomo de la nova kalendaro",
"Take an available name!" => "Prenu haveblan nomon!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendaro kun ĉi tiu nomo jam ekzastas. Se vi malgraŭe daŭros, ĉi tiuj kalendaroj kunfandiĝos.",
"Remove all events from the selected calendar" => "Forigi ĉiujn okazaĵojn el la elektita kalendaro",
"Import" => "Enporti",
"Close Dialog" => "Fermi la dialogon",
"Create a new event" => "Krei okazaĵon",
"Share with:" => "Kunhavigi kun:",
"Shared with" => "Kunhavigita kun",
"Unshare" => "Malkunhavigi",
"Nobody" => "Neniu",
"Shared via calendar" => "Kunhavigita per kalendaro",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "NOTO: agoj sur okazaĵoj kunhavigitaj perkalendare influos la tutan kunhavigon de la kalendaro.",
"View an event" => "Vidi okazaĵon",
"No categories selected" => "Neniu kategorio elektita",
"of" => "de",
"at" => "ĉe",
"General" => "Ĝenerala",
"Timezone" => "Horozono",
"Update timezone automatically" => "Aŭtomate ĝisdatigi la horozonon",
"Time format" => "Horoformo",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Komenci semajnon je",
"Cache" => "Kaŝmemoro",
"Clear cache for repeating events" => "Forviŝi kaŝmemoron por ripeto de okazaĵoj",
"URLs" => "URL-oj",
"Calendar CalDAV syncing addresses" => "sinkronigaj adresoj por CalDAV-kalendaroj",
"more info" => "pli da informo",
"Primary address (Kontact et al)" => "Ĉefa adreso (Kontact kaj aliaj)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "Nurlegebla(j) iCalendar-ligilo(j)"
);

==> owncloud_7.0.11~dfsg.orig.tar.bz2: owncloud/apps/calendar/l10n/eo.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Ne ĉiuj kalendaroj estas tute kaŝmemorigitaj",
"Everything seems to be completely cached" => "Ĉio ŝajnas tute kaŝmemorigita",
"No calendars found." => "Neniu kalendaro troviĝis.",
"No events found." => "Neniu okazaĵo troviĝis.",
"Wrong calendar" => "Malĝusta kalendaro",
"You do not have the permissions to edit this event." => "Vi ne havas la permeson redakti ĉi tiun okazaĵon.",
"The file contained either no events or all events are already saved in your calendar." => "Aŭ la dosiero enhavas neniun okazaĵon aŭ ĉiuj okazaĵoj jam estas konservitaj en via kalendaro.",
"Import failed" => "Enporto malsukcesis",
"New Timezone:" => "Nova horozono:",
"Timezone changed" => "La horozono estas ŝanĝita",
"Invalid request" => "Nevalida peto",
"Calendar" => "Kalendaro",
"Deletion failed" => "Forigo malsukcesis",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd, la d-a de MMMM[ yyyy]{ – [ddd, la d-a de] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd, la d-a de MMMM[ yyyy] HH:mm{ – [ddd, la d-a de MMMM yyyy] HH:mm}",
"group" => "grupo",
"can edit" => "povas redakti",
"can share" => "kunhavebla",
"ddd" => "ddd",
"ddd M/d" => "ddd d/M",
"dddd M/d" => "dddd d/M",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "d'a' de MMM[ yyyy]{ '–' d'a'[ de MMM] yyyy}",
"dddd, MMM d, yyyy" => "dddd, la d-a de MMM yyyy",
"Sunday" => "dimanĉo",
"Monday" => "lundo",
"Tuesday" => "mardo",
"Wednesday" => "merkredo",
"Thursday" => "ĵaŭdo",
"Friday" => "vendredo",
"Saturday" => "sabato",
"Sun." => "dim.",
"Mon." => "lun.",
"Tue." => "mar.",
"Wed." => "mer.",
"Thu." => "ĵaŭ.",
"Fri." => "ven.",
"Sat." => "sab.",
"January" => "Januaro",
"February" => "Februaro",
"March" => "Marto",
"April" => "Aprilo",
"May" => "Majo",
"June" => "Junio",
"July" => "Julio",
"August" => "Aŭgusto",
"September" => "Septembro",
"October" => "Oktobro",
"November" => "Novembro",
"December" => "Decembro",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Maj.",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Aŭg.",
"Sep." => "Sep.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dec.",
"All day" => "La tuta tago",
"New Calendar" => "Nova kalendaro",
"Missing or invalid fields" => "Estas mankantaj aŭ nevalidaj kampoj",
"Title" => "Titolo",
"From Date" => "ekde la dato",
"From Time" => "ekde la horo",
"To Date" => "ĝis la dato",
"To Time" => "ĝis la horo",
"The event ends before it starts" => "La okazaĵo finas antaŭ komenci",
"There was a database fail" => "Datumbaza malsukceso okazis",
"Birthday" => "Naskiĝotago",
"Business" => "Negoco",
"Call" => "Voko",
"Clients" => "Klientoj",
"Deliverer" => "Livero",
"Holidays" => "Ferioj",
"Ideas" => "Ideoj",
"Journey" => "Vojaĝo",
"Jubilee" => "Jubileo",
"Meeting" => "Rendevuo",
"Other" => "Alia",
"Personal" => "Persona",
"Projects" => "Projektoj",
"Questions" => "Demandoj",
"Work" => "Laboro",
"by" => "de",
"unnamed" => "nenomita",
"You do not have the permissions to update this calendar." => "Vi ne havas la permeson ĝisdatigi ĉi tiun kalendaron.",
"You do not have the permissions to delete this calendar." => "Vi ne havas la permeson forigi ĉi tiun kalendaron.",
"You do not have the permissions to add to this calendar." => "Vi ne havas la permeson aldoni al ĉi tiu kalendaro.",
"You do not have the permissions to add events to this calendar." => "Vi ne havas la permeson aldoni okazaĵojn al ĉi tiu kalendaro.",
"You cannot add non-public events to a shared calendar." => "Vi ne povas aldoni nepublikajn okazaĵon al kunhavata kalendaro.",
"You do not have the permissions to delete this event." => "Vi ne havas la permeson forigi ĉi tiun okazaĵon.",
"Busy" => "Okupita",
"Show full event" => "Montri okazaĵon tute",
"Show only busy" => "Montri nur okupitajn",
"Hide event" => "Malmontri okazaĵon",
"Does not repeat" => "Ĉi tio ne ripetiĝas",
"Daily" => "Tage",
"Weekly" => "Semajne",
"Every Weekday" => "Labortage",
"Bi-Weekly" => "Semajnduope",
"Monthly" => "Monate",
"Yearly" => "Jare",
"never" => "neniam",
"by occurrences" => "laŭ aperoj",
"by date" => "laŭ dato",
"by monthday" => "laŭ monattago",
"by weekday" => "laŭ semajntago",
"events week of month" => "la monatsemajno de la okazaĵo",
"first" => "unua",
"second" => "dua",
"third" => "tria",
"fourth" => "kvara",
"fifth" => "kvina",
"last" => "lasta",
"by events date" => "laŭ okazaĵdato",
"by yearday(s)" => "laŭ jartago(j)",
"by weeknumber(s)" => "laŭ semajnnumero(j)",
"by day and month" => "laŭ tago kaj monato",
"Contact birthdays" => "Naskiĝotagoj de la kontaktoj",
"Date" => "Dato",
"Cal." => "Kal.",
"Day" => "Tago",
"Week" => "Semajno",
"Month" => "Monato",
"Today" => "Hodiaŭ",
"CalDav Link" => "CalDav-a ligilo",
"Timezone" => "Horozono",
"Update timezone automatically" => "Aŭtomate ĝisdatigi la horozonon",
"Time format" => "Horoformo",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Komenci semajnon je",
"Cache" => "Kaŝmemoro",
"Clear cache for repeating events" => "Forviŝi kaŝmemoron por ripeto de okazaĵoj",
"Primary CalDAV address" => "Ĉefa CalDAV-adreso",
"iOS/OS X CalDAV address" => "CalDAV-adreso por iOS/OS X",
"Share Calendar" => "Kunhavigi kalendaron",
"Download" => "Elŝuti",
"Edit" => "Redakti",
"Delete" => "Forigi",
"New calendar" => "Nova kalendaro",
"Edit calendar" => "Redakti la kalendaron",
"Edit event" => "Redakti okazaĵon",
"Save event" => "Konservi okazaĵon",
"Delete event" => "Forigi okazaĵon",
"Eventinfo" => "Informo de okazaĵo",
"Repeating" => "Ripetata",
"Alarm" => "Alarmo",
"Attendees" => "Ĉeestontoj",
"Share" => "Kunhavigi",
"Title of the Event" => "Okazaĵotitolo",
"from" => "el",
"to" => "ĝis",
"All Day Event" => "La tuta tago",
"Advanced options" => "Altnivela agordo",
"Location" => "Loko",
"Categories (separate by comma)" => "Kategorioj (apartigu per komo)",
"Edit categories" => "Redakti kategoriojn",
"Description" => "Priskribo",
"Export event" => "Malenporti okazaĵon",
"Repeat" => "Ripeti",
"Advanced" => "Altnivelo",
"Select weekdays" => "Elekti semajntagojn",
"Select days" => "Elekti tagojn",
"and the events day of year." => "kaj la jartago de la okazaĵo.",
"and the events day of month." => "kaj la monattago de la okazaĵo.",
"Select months" => "Elekti monatojn",
"Select weeks" => "Elekti semajnojn",
"and the events week of year." => "kaj la jarsemajno de la okazaĵo.",
"Interval" => "Intervalo",
"End" => "Fino",
"occurrences" => "aperoj",
"Visibility to people shared with" => "Videblo por uloj kunhavantaj",
"create a new calendar" => "Krei novan kalendaron",
"Import a calendar file" => "Enporti kalendarodosieron",
"Please choose a calendar" => "Bonvolu elekti kalendaron",
"Name of new calendar" => "Nomo de la nova kalendaro",
"Take an available name!" => "Prenu haveblan nomon!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendaro kun ĉi tiu nomo jam ekzastas. Se vi malgraŭe daŭros, ĉi tiuj kalendaroj kunfandiĝos.",
"Remove all events from the selected calendar" => "Forigi ĉiujn okazaĵojn el la elektita kalendaro",
"Import" => "Enporti",
"Close Dialog" => "Fermi la dialogon",
"Create a new event" => "Krei okazaĵon",
"Create event" => "Krei okazaĵon",
"Share with user or group" => "Kunhavigi kun uzanto aŭ grupo",
"Unshare" => "Malkunhavigi",
"Not shared with anyone" => "Kunhavigata kun neniu",
"Send Email" => "Sendi retpoŝton",
"Shared via calendar" => "Kunhavigita per kalendaro",
"Not shared with anyone via calendar" => "Kunhavigata kun neniu per kalendaro",
"View an event" => "Vidi okazaĵon",
"Category" => "Kategorio",
"No categories selected" => "Neniu kategorio elektita",
"%s of %s" => "%s el %s",
"Access Class" => "Alirpermesa klaso",
"From" => "Ekde",
"at" => "ĉe",
"To" => "Ĝis"
);
